@@ -227,11 +227,12 @@ get_location_cb (EphyLocationEntry      *entry,
                  EphyLocationController *controller)
 {
   EphyEmbed *embed;
+  const char *address;
 
-  embed = ephy_embed_container_get_active_child
-            (EPHY_EMBED_CONTAINER (controller->window));
+  embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (controller->window));
+  address = ephy_web_view_get_address (ephy_embed_get_web_view (embed));
 
-  return g_strdup (ephy_web_view_get_address (ephy_embed_get_web_view (embed)));
+  return ephy_embed_utils_is_no_show_address (address) ? NULL : g_strdup (address);
 }
 
 static char *
